<?php
/**
 * @file
 * Module file for the features_cicivrm module, which enables
 * the capture and management of civicrm entities in Drupal.
 */

/**
 * Implements hook_features_export_options().
 */
function contact_features_export_options() {
  $options = array();
  $api_contact_api = features_civicrm_api('Contact', 'get', array('contact_id' => 1));
  foreach ($api_contact_api['values'] as $contact) {
    $options[$contact['id']] = $contact['display_name'];
  }
  return $options;
}

/**
 * Implements hook_features_export().
 */
function contact_features_export($data, &$export, $module_name = '') {
  $export['dependencies']['civicrm'] = 'civicrm';
  $export['dependencies']['features_civicrm'] = 'features_civicrm';
  $export['dependencies']['features'] = 'features';
  $options = contact_features_export_options();
  foreach ($data as $contact_id) {
    $export['features']['contact'][$contact_id] = $contact_id;
  }
  return array();
}

/**
 * Implements hook_features_export_render().
 */
function contact_features_export_render($module_name, $data, $export = NULL) {
  $contacts = array();
  $options = contact_features_export_options();
  foreach ($data as $contact_id_key => $contact_id) {
    $contact_name = $options[$contact_id];
    $contacts[$contact_id] = $contact_name;
  }

  $code = array();
  $code[] = '  $civicrm_contact = array();';
  $code[] = '';
  $contact_fields = features_civicrm_api('contact', 'getfields');
  $contact_fields = $contact_fields['values'];
  foreach ($contacts as $contact_id => $contact_name) {
    $contact_api_result = features_civicrm_api('contact', 'get', array('id' => $contact_id));
    $contact_api_result = $contact_api_result['values'][$contact_id];
    $contact_code = features_var_export($contact_api_result);
    $code[] = "  \$civicrm_contact['{$contact_id}'] = {$contact_code};";
  }
  $code[] = '  return $civicrm_contact;';
  $code = implode("\n", $code);
  return array('civicrm_default_contact' => $code);
}

/**
 * Implements hook_features_rebuild().
 */
function contact_features_rebuild($module) {
  contact_features_revert($module);
}

/**
 * Implements hook_features_revert().
 */
function contact_features_revert($module) {
  $civicrm_contacts = module_invoke($module, 'civicrm_default_contact');
  foreach ($civicrm_contacts as $contact) {
    $existing_contact = features_civicrm_api('contact', 'get', array('id' => $contact['id']));
    // Merge with code_contact.
    $merged_contact = array_merge_recursive_distinct($existing_contact['values'][$existing_contact['id']], $contact);
    $api_contacts_api = features_civicrm_api('contact', 'create', $merged_contact);
  }
}
