<?php
/**
 * @file
 * Module file for the features_cicivrm module, which enables
 * the capture and management of civicrm entities in Drupal.
 */

/**
 * Implements hook_features_export_options().
 */
function domain_features_export_options() {
  $options = array();
  $api_domains_api = features_civicrm_api('Domain', 'get');
  foreach ($api_domains_api['values'] as $domain) {
    $options[$domain['id']] = $domain['name'];
  }
  return $options;
}

/**
 * Implements hook_features_export().
 */
function domain_features_export($data, &$export, $module_name = '') {
  $export['dependencies']['civicrm'] = 'civicrm';
  $export['dependencies']['features_civicrm'] = 'features_civicrm';
  $export['dependencies']['features'] = 'features';
  $options = domain_features_export_options();
  foreach ($data as $domain_id) {
    $export['features']['domain'][$domain_id] = $domain_id;
    $domain_api_result = features_civicrm_api('Domain', 'get', array('id' => $domain_id));
    $domain_api_result = $domain_api_result['values'][$domain_id];
    $contact_id = $domain_api_result['contact_id'];
    $export['features']['contact'][$contact_id] = $contact_id;
  }
  return array();
}

/**
 * Implements hook_features_export_render().
 */
function domain_features_export_render($module_name, $data, $export = NULL) {
  $domains = array();
  $options = domain_features_export_options();
  foreach ($data as $domain_id_key => $domain_id) {
    $domain_name = $options[$domain_id];
    $domains[$domain_id] = $domain_name;
  }

  $code = array();
  $code[] = '  $civicrm_domain = array();';
  $code[] = '';
  $domain_fields = features_civicrm_api('Domain', 'getfields');
  $domain_fields = $domain_fields['values'];
  foreach ($domains as $domain_id => $domain_name) {
    $domain_api_result = features_civicrm_api('Domain', 'get', array('id' => $domain_id));
    $domain_api_result = $domain_api_result['values'][$domain_id];
    // Remove fields not in getFields.
    foreach ($domain_api_result as $domain_api_field_name => $domain_api_field_value) {
      if (!isset($domain_fields[$domain_api_field_name])) {
        unset($domain_api_result[$domain_api_field_name]);
      }
    }
    $domain_api_result['config_backend']
      = unserialize($domain_api_result['config_backend']);
    foreach ($domain_api_result['config_backend'] as $config_element_id => $config_element) {
      if (is_object($config_element)) {
        $config_element_serialized = array();
        $config_element_serialized['serialized'] = serialize($config_element);
        $config_element_serialized['is_serialized_object'] = TRUE;
        $domain_api_result['config_backend'][$config_element_id] = $config_element_serialized;
      }
    }
    $domain_code = var_export($domain_api_result, TRUE);
    $code[] = "  \$civicrm_domain['{$domain_id}'] = {$domain_code};";
  }
  $code[] = '  return $civicrm_domain;';
  $code = implode("\n", $code);
  return array('civicrm_default_domain' => $code);
}

/**
 * Implements hook_features_rebuild().
 */
function domain_features_rebuild($module) {
  domain_features_revert($module);
}

/**
 * Implements hook_features_revert().
 */
function domain_features_revert($module) {
  $civicrm_domains = module_invoke($module, 'civicrm_default_domain');
  foreach ($civicrm_domains as $domain) {
    $existing_domain = features_civicrm_api('Domain', 'get', array('id' => $domain['id']));
    // Merge with code_domain.
    $merged_domain = array_merge_recursive_distinct($existing_domain['values'][$existing_domain['id']], $domain);
    // Rebuild serialized object in config_backend.
    foreach ($merged_domain['config_backend'] as $config_element_id => $config_element) {
      if (isset($config_element['is_serialized_object']) && $config_element['is_serialized_object']) {
        $merged_domain['config_backend'][$config_element_id] = unserialize($config_element['serialized']);
      }
    }
    $merged_domain['config_backend'] = serialize($merged_domain['config_backend']);
    $api_domains_api = features_civicrm_api('Domain', 'create', $merged_domain);
  }
}
