<?php
/**
 * @file
 * Module file for the features_cicivrm module, which enables
 * the capture and management of civicrm entities in Drupal.
 */

/**
 * Implements hook_features_export_options().
 */
function relationshiptype_features_export_options() {
  $options = array();
  $api_relationshiptype_api = features_civicrm_api('RelationshipType', 'get');
  foreach ($api_relationshiptype_api['values'] as $relationshiptype) {
    $options[$relationshiptype['name_a_b']] = $relationshiptype['name_a_b'];
  }
  return $options;
}

/**
 * Implements hook_features_export().
 */
function relationshiptype_features_export($data, &$export, $module_name = '') {
  $export['dependencies']['civicrm'] = 'civicrm';
  $export['dependencies']['features_civicrm'] = 'features_civicrm';
  $export['dependencies']['features'] = 'features';
  foreach ($data as $relationshiptype) {
    $export['features']['relationshiptype'][$relationshiptype] = $relationshiptype;
  }
  return array();
}

/**
 * Implements hook_features_export_render().
 */
function relationshiptype_features_export_render($module_name, $data, $export = NULL) {
  $code = array();
  $code[] = '  $civicrm_relationshiptype = array();';
  $code[] = '';
  foreach ($data as $relationshiptype_key => $relationshiptype_value) {
    $relationshiptype_api_result
      = features_civicrm_api('RelationshipType', 'get', array('name_a_b' => $relationshiptype_value));
    $relationshiptype_id = $relationshiptype_api_result['id'];
    $relationshiptype_api_result = $relationshiptype_api_result['values'][$relationshiptype_id];
    unset($relationshiptype_api_result['id']);
    $relationshiptype_code = features_var_export($relationshiptype_api_result);
    $code[] = "  \$civicrm_relationshiptype['{$relationshiptype_value}'] = {$relationshiptype_code};";
  }
  $code[] = '  return $civicrm_relationshiptype;';
  $code = implode("\n", $code);
  return array('civicrm_default_relationshiptype' => $code);
}

/**
 * Implements hook_features_rebuild().
 */
function relationshiptype_features_rebuild($module) {
  relationshiptype_features_revert($module);
}

/**
 * Implements hook_features_revert().
 */
function relationshiptype_features_revert($module) {
  $civicrm_relationshiptypes = module_invoke($module, 'civicrm_default_relationshiptype');
  foreach ($civicrm_relationshiptypes as $relationshiptype) {
    $existing_relationshiptype = features_civicrm_api('RelationshipType', 'get', array('id' => $relationshiptype['name_a_b']));
    // Merge with code_relationshiptype.
    $merged_relationshiptype = array_merge_recursive_distinct($existing_relationshiptype['values'][$existing_relationshiptype['id']], $relationshiptype);
    $api_relationshiptypes_api = features_civicrm_api('RelationshipType', 'create', $merged_relationshiptype);
  }
}
