<?php
/**
 * @file
 * Module file for the features_cicivrm module, which enables
 * the capture and management of civicrm entities in Drupal.
 */

/**
 * Implements hook_features_export_options().
 */
function setting_features_export_options() {
  $options = array();
  $api_setting_api = features_civicrm_api('setting', 'getfields');
  foreach ($api_setting_api['values'] as $setting) {
    if (isset($setting['title']) && $setting['title'] != '') {
      $options[$setting['name']] = $setting['title'];
    }
    else {
      $options[$setting['name']] = $setting['name'];
    }
  }
  return $options;
}

/**
 * Implements hook_features_export().
 */
function setting_features_export($data, &$export, $module_name = '') {
  $export['dependencies']['civicrm'] = 'civicrm';
  $export['dependencies']['features_civicrm'] = 'features_civicrm';
  $export['dependencies']['features'] = 'features';
  foreach ($data as $setting) {
    $export['features']['setting'][$setting] = $setting;
  }
  return array();
}

/**
 * Implements hook_features_export_render().
 */
function setting_features_export_render($module_name, $data, $export = NULL) {
  $code = array();
  $code[] = '  $civicrm_setting = array();';
  $code[] = '';
  $setting_api_result = features_civicrm_api('setting', 'get');
  if ($setting_api_result['is_error'] == 0) {
    $setting_id = $setting_api_result['id'];
    $setting_api_result = $setting_api_result['values'];
    foreach ($data as $setting_key => $setting_value) {
      $setting_code = features_var_export($setting_api_result[$setting_id][$setting_value]);
      $code[] = "  \$civicrm_setting['{$setting_value}'] = {$setting_code};";
    }
  }
  $code[] = '  return $civicrm_setting;';
  $code = implode("\n", $code);
  return array('civicrm_default_setting' => $code);
}

/**
 * Implements hook_features_rebuild().
 */
function setting_features_rebuild($module) {
  setting_features_revert($module);
}

/**
 * Implements hook_features_revert().
 */
function setting_features_revert($module) {
  $code_settings = module_invoke($module, 'civicrm_default_setting');
  $code_settings += array('domain_id' => 'all');
  $settings_api = features_civicrm_api('Setting', 'create', $code_settings);
}
